@@ -1,5 +1,5 @@
 OneFileHierarchy<- function (MyHier) {
-	res<-xmlToList(xmlRoot(xmlParse(MyHier, getDTD=FALSE)), simplify=FALSE)
+	res <- PageProcessing(MyHier)
 	resTaxonOnly <- which(names(res) == "Taxon")
 	resMat <- matrix(nrow=length(resTaxonOnly), ncol=7)
 	for(j in resTaxonOnly) {
@@ -20,6 +20,6 @@ OneFileHierarchy<- function (MyHier) {
 		resMat[j,] <- c(a,b,c,d,e,f,g)
 	}
 	colnames(resMat) <- c("scientificName", "taxonRank", "taxonomicStatus", "eolID", "parentNameUsageID", "taxonID", "identifier")
-    resMat[,2] <- gsub("\\b(\\w)", "\\U\\1", resMat[,2], perl=T)  #cap all taxon ranks for downstream combining
+    resMat[,2] <- gsub("\\b(\\w)", "\\U\\1", resMat[,2], perl=TRUE)  #cap all taxon ranks for downstream combining
 	return(resMat)		
 }
